/*
 * @Description: 包装规则相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-06-22 20:38:07
 */

import { ActionItem, BasicColumn } from '/@/components/Table';
import { buildUUID } from '/@/utils/uuid';

function _default() {
  /**
   * @description: 自定义编辑方法，跳转到高级页面
   * @param {Fn} args
   * @param {*} params
   * @return {*}
   */
  function pkgGrpEdit(go: Fn, params: {}) {
    const param = {
      CODE: params['record']['RULE_CODE'],
      ID: params['record']['ID'],
      Name: 'BAS_PKG_DTL',
      Title: `编辑包装规则：${params['record']['RULE_CODE']}`,
      pCode: 'PKG_RULE_ID',
      IsID: true,
    };
    go(`/BAS_PKG_DTL/High/${encodeURI(JSON.stringify(param))}`);
  }

  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };

  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (fnName: string) => {
      return {
        action: 'go', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
        url: 'BAS_PKG_DTL/High',
        params: {
          CODE: '0',
          ID: buildUUID(),
          Name: 'BAS_PKG_DTL',
          Title: '新增包装规则',
          pCode: 'PKG_RULE_ID',
          IsID: true,
        },
      };
    },
    /**
     * @description: 产品绑定工艺路线操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      data[0].onClick = pkgGrpEdit.bind(null, args[5], params);
      return data;
    },
  };

  return [methods, ActionColumn];
}

export default _default;
